@@ -206,7 +206,7 @@ class TidalAPI(object):
         if msg is not None:
             return msg, None
         resp = dictToModel(data, __StreamRespon__())
-        manifest = json.loads(base64.b64decode(resp.manifest))
+        manifest = json.loads(base64.b64decode(resp.manifest).decode('utf-8'))
         if "vnd.tidal.bt" in resp.manifestMimeType:
             ret = StreamUrl()
             ret.trackid = resp.trackid
@@ -223,7 +223,7 @@ class TidalAPI(object):
         if msg is not None:
             return msg, None
         resp = dictToModel(data, __StreamRespon__())
-        manifest = json.loads(base64.b64decode(resp.manifest))
+        manifest = json.loads(base64.b64decode(resp.manifest).decode('utf-8'))
         if "vnd.tidal.emu" in resp.manifestMimeType:
             array = self.__getResolutionList__(manifest['urls'][0])
             icmp = int(quality.value)
